```{include} ../README.md
:start-line: 0
:end-line: 3
```

- Get started with [Quickstart](guide/quickstart).
- Check out the [API](api).

```{toctree}
:maxdepth: 1
:hidden:

guide/index
api
changelog
```
